@@ -43,8 +43,8 @@
 #ifndef __GST_RTSP_DEFS_H__
 #define __GST_RTSP_DEFS_H__
 
-#include <glib.h>
-#include <glib-object.h>
+#include <gst/gst.h>
+#include <gst/rtsp/rtsp-prelude.h>
 
 G_BEGIN_DECLS
 
@@ -72,7 +72,7 @@ G_STMT_START { \
  * @GST_RTSP_ERESOLV: a host resolve error occured
  * @GST_RTSP_ENOTIMPL: function not implemented
  * @GST_RTSP_ESYS: a system error occured, errno contains more details
- * @GST_RTSP_EPARSE: a persing error occured
+ * @GST_RTSP_EPARSE: a parsing error occured
  * @GST_RTSP_EWSASTART: windows networking could not start
  * @GST_RTSP_EWSAVERSION: windows networking stack has wrong version
  * @GST_RTSP_EEOF: end-of-file was reached
@@ -159,13 +159,15 @@ typedef enum {
  * @GST_RTSP_VERSION_INVALID: unknown/invalid version
  * @GST_RTSP_VERSION_1_0: version 1.0
  * @GST_RTSP_VERSION_1_1: version 1.1.
+ * @GST_RTSP_VERSION_2_0: version 2.0.
  *
  * The supported RTSP versions.
  */
 typedef enum {
   GST_RTSP_VERSION_INVALID = 0x00,
   GST_RTSP_VERSION_1_0     = 0x10,
-  GST_RTSP_VERSION_1_1     = 0x11
+  GST_RTSP_VERSION_1_1     = 0x11,
+  GST_RTSP_VERSION_2_0     = 0x20
 } GstRTSPVersion;
 
 /**
@@ -333,6 +335,16 @@ typedef enum {
   /* Since 1.4 */
   GST_RTSP_HDR_KEYMGMT,             /* KeyMgmt */
 
+  /* Since 1.14 */
+  GST_RTSP_HDR_PIPELINED_REQUESTS,  /* Pipelined-Requests Rr     opt.      SETUP */
+  GST_RTSP_HDR_MEDIA_PROPERTIES,    /* Media-Properties   Rr     opt.      SETUP */
+  GST_RTSP_HDR_SEEK_STYLE,          /* Seek-Type          Rr     opt.      PLAY */
+  GST_RTSP_HDR_ACCEPT_RANGES,       /* Accept-Ranges      Rr     opt.      SETUP, GET_PARAMETER */
+
+  /* Onvif extensions */
+  GST_RTSP_HDR_FRAMES,              /* Frames             Rr     opt.      PLAY */
+  GST_RTSP_HDR_RATE_CONTROL,        /* Rate-control       Rr     opt.      PLAY */
+
   GST_RTSP_HDR_LAST
 } GstRTSPHeaderField;
 
@@ -390,21 +402,52 @@ typedef enum {
   GST_RTSP_STS_OPTION_NOT_SUPPORTED                 = 551
 } GstRTSPStatusCode;
 
+GST_RTSP_API
 gchar*             gst_rtsp_strresult          (GstRTSPResult result);
 
+GST_RTSP_API
 const gchar*       gst_rtsp_method_as_text     (GstRTSPMethod method);
+
+GST_RTSP_API
 const gchar*       gst_rtsp_version_as_text    (GstRTSPVersion version);
+
+GST_RTSP_API
 const gchar*       gst_rtsp_header_as_text     (GstRTSPHeaderField field);
+
+GST_RTSP_API
 const gchar*       gst_rtsp_status_as_text     (GstRTSPStatusCode code);
 
+GST_RTSP_API
 gchar*             gst_rtsp_options_as_text    (GstRTSPMethod options);
+
+GST_RTSP_API
 GstRTSPMethod      gst_rtsp_options_from_text  (const gchar *options);
 
+GST_RTSP_API
 GstRTSPHeaderField gst_rtsp_find_header_field  (const gchar *header);
+
+GST_RTSP_API
 GstRTSPMethod      gst_rtsp_find_method        (const gchar *method);
 
+GST_RTSP_API
 gboolean           gst_rtsp_header_allow_multiple (GstRTSPHeaderField field);
 
+GST_RTSP_API
+gchar *            gst_rtsp_generate_digest_auth_response (const gchar *algorithm,
+                                                           const gchar *method,
+                                                           const gchar *realm,
+                                                           const gchar *username,
+                                                           const gchar *password,
+                                                           const gchar *uri,
+                                                           const gchar *nonce);
+
+GST_RTSP_API
+gchar *            gst_rtsp_generate_digest_auth_response_from_md5 (const gchar *algorithm,
+                                                                    const gchar * method,
+                                                                    const gchar * md5,
+                                                                    const gchar * uri,
+                                                                    const gchar * nonce);
+
 G_END_DECLS
 
 #endif /* __GST_RTSP_DEFS_H__ */
